@@ -109,6 +109,10 @@ GdkPixmap *                 eel_background_get_pixmap_and_color             (Eel
 									     gboolean                    *changes_with_size);
 									     
 
+/* Helper function for widgets using EelBackground */
+void                        eel_background_expose                           (GtkWidget                   *widget,
+									     GdkEventExpose              *event);
+
 /* For preping the background to be used in one of the two calls
  * below. Only intended to be called by eel_background_canvas_group_update.
  */
