@@ -61,7 +61,7 @@ test_window_new (const char *title, guint border_width)
 			    G_CALLBACK (test_delete_event),
 			    NULL);
 	
-	gtk_window_set_policy (GTK_WINDOW (window), TRUE, TRUE, FALSE);
+	gtk_window_set_resizable (GTK_WINDOW (window), TRUE);
 	gtk_container_set_border_width (GTK_CONTAINER (window), border_width);
 	
 	return window;
